@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_spherical_topology_traits_2_impl.h $
-// $Id: Arr_spherical_topology_traits_2_impl.h 12a85a9 2021-03-01T15:39:36+02:00 Efi Fogel
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_spherical_topology_traits_2_impl.h $
+// $Id: include/CGAL/Arr_topology_traits/Arr_spherical_topology_traits_2_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Efi Fogel         <efif@post.tau.ac.il>
@@ -189,6 +189,7 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
   auto cmp_x_op = m_geom_traits->compare_x_2_object();
   auto cmp_y_at_x_op = m_geom_traits->compare_y_at_x_2_object();
   auto cmp_x_pt_ce = m_geom_traits->compare_x_point_curve_end_2_object();
+  auto cmp_x_ce_ce = m_geom_traits->compare_x_curve_ends_2_object();
   auto is_vertical = m_geom_traits->is_vertical_2_object();
   auto is_on_y_identification = m_geom_traits->is_on_y_identification_2_object();
 
@@ -215,16 +216,16 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
 
     /*! We identify 2 main cases:
      * 1. The vertical ray intersects the boundary at a halfedge. In this
-     * case the x-possition of p is strictly larger than the x-possition of
-     * the current-curve source, and strictly smaller than x-possition of
-     * the current-curve target, or vise versa.
+     * case the x-position of p is strictly larger than the x-position of
+     * the current-curve source, and strictly smaller than x-position of
+     * the current-curve target, or vice versa.
      * 2. The vertical ray intersects the boundary at a vertex. In this case:
-     * a. the x-possition of p is strictly smaller than the x-position of the
+     * a. the x-position of p is strictly smaller than the x-position of the
      * current-curve source, and equal to the x-position of the current-curve
      * target, and
-     * b. the x-possition of p is equal to the x-position of the next-curve
+     * b. the x-position of p is equal to the x-position of the next-curve
      * source (not counting vertical curves in between), and strictly larger
-     * than the x-possition of the next-curve target, or vise verase (that is,
+     * than the x-position of the next-curve target, or vice verase (that is,
      * the "smaller" and "larger" interchanged).
      */
 
@@ -252,7 +253,6 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
     Arr_parameter_space ps_y_target;
 
     do {
-
       /* Compare p to the target vertex of the current halfedge. If the
        * vertex v is on the boundary of the component, p is not in the interior
        * the face.
@@ -262,18 +262,19 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
       // Ignore vertical curves:
       if (is_vertical(curr->curve())) {
         /* If this outer ccb chain contains the north pole, and our point
-         * lies horizontaly between the two vertical curves that meet at
+         * lies horizontally between the two vertical curves that meet at
          * the north pole, increase the intersection counter
          */
         if (curr->direction() == ARR_LEFT_TO_RIGHT) {
-          auto ps_y_1 = ps_y_op(curr->curve(), ARR_MAX_END);
-          auto ps_y_2 = ps_y_op(curr->next()->curve(), ARR_MAX_END);
+          const auto& cv1 = curr->curve();
+          const auto& cv2 = curr->next()->curve();
+          auto ps_y_1 = ps_y_op(cv1, ARR_MAX_END);
+          auto ps_y_2 = ps_y_op(cv2, ARR_MAX_END);
           if ((ps_y_1 == ARR_TOP_BOUNDARY) && (ps_y_2 == ARR_TOP_BOUNDARY)) {
             // Compare the x-coordinates:
-            const auto& cv1 = curr->curve();
-            const auto& cv2 = curr->next()->curve();
             Comparison_result rc1, rc2;
             if (is_on_y_identification(cv1)) {
+              if (is_on_y_identification(p)) return false;
               // -----------
               // |     |  |<---- cv1 go
               // |     |  ||
@@ -286,6 +287,7 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
               rc2 = cmp_x_pt_ce(p, cv2, ARR_MAX_END);
             }
             else if (is_on_y_identification(cv2)) {
+              if (is_on_y_identification(p)) return false;
               //       -----------
               // cv2--->|  |     |
               //       ||  |     |
@@ -297,7 +299,14 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
               rc1 = cmp_x_pt_ce(p, cv1, ARR_MAX_END);
               rc2 = LARGER;
             }
+            else if (is_on_y_identification(p)) {
+              // If the max end of cv1 is smaller than the max end of cv2,
+              // the identification x-coordinate is in the x-range.
+              rc1 = cmp_x_ce_ce(cv1, ARR_MAX_END, cv2, ARR_MAX_END);
+              rc2 = LARGER;
+            }
             else {
+              // None of p, cv1, or cv2 lie on the identification curve.
               rc1 = cmp_x_pt_ce(p, cv1, ARR_MAX_END);
               rc2 = cmp_x_pt_ce(p, cv2, ARR_MAX_END);
             }
@@ -478,7 +487,7 @@ are_equal(const Vertex* v,
 
   CGAL_assertion(ps_x != ARR_INTERIOR);
   /* Both vertices have the same x boundary conditions =>
-   * comapare their y-position.
+   * compare their y-position.
    */
   const Point_2& p1 = v->point();
   const Point_2& p2 = (ind == ARR_MIN_END) ?
@@ -563,8 +572,8 @@ let_me_decide_the_outer_ccb(std::pair< CGAL::Sign, CGAL::Sign> signs1,
  * represent the curve end along the face boundary.
  */
 template <typename GeomTraits, typename Dcel>
-boost::optional
-  <boost::variant
+std::optional
+  <std::variant
     <typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Vertex*,
      typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Halfedge*> >
 Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
@@ -577,17 +586,17 @@ place_boundary_vertex(Face* /* f */,
                       ,
                       Arr_parameter_space ps_y)
 {
-  typedef boost::variant<Vertex*, Halfedge*>    Non_optional_result;
-  typedef boost::optional<Non_optional_result>  Result;
+  typedef std::variant<Vertex*, Halfedge*>    Non_optional_result;
+  typedef std::optional<Non_optional_result>  Result;
 
   // Rcpp::Rcout << "place_boundary_vertex()" << std::endl;
   if (ps_y == ARR_BOTTOM_BOUNDARY) {
-    if (m_south_pole == nullptr) return boost::none;
+    if (m_south_pole == nullptr) return std::nullopt;
     return Result(Non_optional_result(m_south_pole));
   }
 
   if (ps_y == ARR_TOP_BOUNDARY) {
-    if (m_north_pole == nullptr) return boost::none;
+    if (m_north_pole == nullptr) return std::nullopt;
     return Result(Non_optional_result(m_north_pole));
   }
 
@@ -603,7 +612,7 @@ place_boundary_vertex(Face* /* f */,
   }
 
   // The vertex hasn't been created yet, return a null object:
-  return boost::none;
+  return std::nullopt;
 }
 
 /*! \brief locate the predecessor halfedge for the given curve around a given
@@ -639,7 +648,7 @@ locate_around_boundary_vertex(Vertex* v,
 
 /*! \brief locates a DCEL feature that contains a given curve end. */
 template <typename GeomTraits, typename Dcel>
-boost::variant
+std::variant
 <typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Vertex*,
  typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Halfedge*,
  typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Face*>
@@ -652,7 +661,7 @@ locate_curve_end(const X_monotone_curve_2& xc, Arr_curve_end ind,
                  ,
                  Arr_parameter_space ps_y)
 {
-  typedef boost::variant<Vertex*, Halfedge*, Face*>     Result;
+  typedef std::variant<Vertex*, Halfedge*, Face*>     Result;
   // Act according to the boundary conditions.
   if (ps_y == ARR_TOP_BOUNDARY) {
     // In case the curve end coincides with the north pole, return the vertex
@@ -894,7 +903,7 @@ _locate_around_pole(Vertex* v,
     next = curr->next()->opposite();
   } while (curr != first);
 
-  // We sould never reach here:
+  // We should never reach here:
   CGAL_error();
   return nullptr;
 }
@@ -981,3 +990,4 @@ _face_below_vertex_on_discontinuity(Vertex* v) const
 } //namespace CGAL
 
 #endif
+
