@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Barycentric_coordinates_2/include/CGAL/Barycentric_coordinates_2/triangle_coordinates_2.h $
-// $Id: triangle_coordinates_2.h 0e84898 2022-05-13T15:50:21+02:00 Sebastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Barycentric_coordinates_2/include/CGAL/Barycentric_coordinates_2/triangle_coordinates_2.h $
+// $Id: include/CGAL/Barycentric_coordinates_2/triangle_coordinates_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -258,7 +258,7 @@ namespace Barycentric_coordinates {
     /// Computes triangle barycentric coordinates for a chosen query point with respect to all three vertices of the triangle.
     /// Computed coordinates are stored in the output iterator `output`.
     template<class OutputIterator>
-    inline boost::optional<OutputIterator> operator()(
+    inline std::optional<OutputIterator> operator()(
       const Point_2 &query_point, OutputIterator output)
     {
       return triangle_coordinates_2(query_point, output);
@@ -299,7 +299,7 @@ namespace Barycentric_coordinates {
     // This function accepts a container of the type <a href="https://en.cppreference.com/w/cpp/container/vector">`std::vector`</a>
     // and returns an iterator of the type <a href="https://en.cppreference.com/w/cpp/iterator/back_insert_iterator">`std::back_insert_iterator`</a>
     // that is placed past-the-end of the resulting sequence of coordinate values.
-    inline boost::optional<std::back_insert_iterator<std::vector<FT> > > operator()(
+    inline std::optional<std::back_insert_iterator<std::vector<FT> > > operator()(
       const Point_2 &query_point, std::vector<FT> &output_vector)
     {
       output_vector.reserve(output_vector.size() + 3);
@@ -348,7 +348,7 @@ namespace Barycentric_coordinates {
 
     // Compute triangle coordinates.
     template<class OutputIterator>
-    boost::optional<OutputIterator> triangle_coordinates_2(
+    std::optional<OutputIterator> triangle_coordinates_2(
       const Point_2 &query_point, OutputIterator &output) {
 
       // Compute some related sub-areas.
@@ -373,7 +373,7 @@ namespace Barycentric_coordinates {
       ++output;
 
       // Output all coordinates.
-      return boost::optional<OutputIterator>(output);
+      return std::optional<OutputIterator>(output);
     }
   };
 
