@@ -4,15 +4,15 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/GraphicsView/include/CGAL/Buffer_for_vao.h $
-// $Id: Buffer_for_vao.h 4547818 2022-11-15T13:39:40+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Basic_viewer/include/CGAL/Buffer_for_vao.h $
+// $Id: include/CGAL/Buffer_for_vao.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
 
-#ifndef CGAL_VBO_BUFFER_FILLER_H
-#define CGAL_VBO_BUFFER_FILLER_H
+#ifndef CGAL_BUFFER_FOR_VAO_H
+#define CGAL_BUFFER_FOR_VAO_H
 
 #include <CGAL/license/GraphicsView.h>
 
@@ -126,13 +126,43 @@ namespace internal
     static const typename Local_kernel::Ray_2& get_local_ray(const typename Local_kernel::Ray_2& r)
     { return r; }
   };
+
+  template<typename CDT>
+  void mark_domains(CDT& tri,
+                    typename CDT::Face_handle start, int index,
+                    std::queue<typename CDT::Edge>& border)
+  {
+    if (start->info().m_nesting_level!=-1) return;
+    std::queue<typename CDT::Face_handle> queue;
+    queue.push(start);
+    while (!queue.empty())
+    {
+      auto fh=queue.front();
+      queue.pop();
+      if (fh->info().m_nesting_level==-1)
+      {
+        fh->info().m_nesting_level=index;
+        for (int i = 0; i < 3; i++)
+        {
+          typename CDT::Edge e(fh,i);
+          auto n = fh->neighbor(i);
+          if (n->info().m_nesting_level==-1)
+          {
+            if (tri.is_constrained(e)) { border.push(e); }
+            else { queue.push(n); }
+          }
+        }
+      }
+    }
+  }
 } // End namespace internal
 
 //------------------------------------------------------------------------------
-template<typename BufferType=float, typename IndexType=std::size_t>
 class Buffer_for_vao
 {
 public:
+  using BufferType=float;
+  using IndexType=std::size_t;
   typedef CGAL::Exact_predicates_inexact_constructions_kernel Local_kernel;
   typedef Local_kernel::Point_3  Local_point;
   typedef Local_kernel::Vector_3 Local_vector;
@@ -164,6 +194,7 @@ public:
     if (m_index_buffer!=nullptr)          { m_index_buffer->clear(); }
     if (m_flat_normal_buffer!=nullptr)    { m_flat_normal_buffer->clear(); }
     if (m_gouraud_normal_buffer!=nullptr) { m_gouraud_normal_buffer->clear(); }
+    if (m_bb!=nullptr)                    { (*m_bb)=CGAL::Bbox_3(); }
 
     m_zero_x=true;
     m_zero_y=true;
@@ -204,11 +235,10 @@ public:
   bool has_zero_z() const
   { return m_zero_z; }
 
-  void negate_normals()
+  void negate_normals() const
   {
     m_inverse_normal=!m_inverse_normal;
-    for (std::vector<BufferType>*array=m_flat_normal_buffer; array!=nullptr;
-         array=(array==m_gouraud_normal_buffer?nullptr:m_gouraud_normal_buffer))
+    for (std::vector<BufferType>*array: {m_flat_normal_buffer, m_gouraud_normal_buffer})
     {
       for (std::size_t i=0; i<array->size(); ++i)
       { (*array)[i]=-(*array)[i]; }
@@ -459,31 +489,31 @@ public:
 
   /// adds `kp` coordinates to `buffer`
   template<typename KPoint>
-  static void add_point_in_buffer(const KPoint& kp, std::vector<float>& buffer)
+  static void add_point_in_buffer(const KPoint& kp, std::vector<BufferType>& buffer)
   {
     Local_point p=get_local_point(kp);
-    buffer.push_back(static_cast<float>(p.x()));
-    buffer.push_back(static_cast<float>(p.y()));
-    buffer.push_back(static_cast<float>(p.z()));
+    buffer.push_back(static_cast<BufferType>(p.x()));
+    buffer.push_back(static_cast<BufferType>(p.y()));
+    buffer.push_back(static_cast<BufferType>(p.z()));
   }
 
   /// adds `kv` coordinates to `buffer`
   template<typename KVector>
-  static void add_normal_in_buffer(const KVector& kv, std::vector<float>& buffer,
+  static void add_normal_in_buffer(const KVector& kv, std::vector<BufferType>& buffer,
                                    bool inverse_normal=false)
   {
     Local_vector n=(inverse_normal?-get_local_vector(kv):get_local_vector(kv));
-    buffer.push_back(static_cast<float>(n.x()));
-    buffer.push_back(static_cast<float>(n.y()));
-    buffer.push_back(static_cast<float>(n.z()));
+    buffer.push_back(static_cast<BufferType>(n.x()));
+    buffer.push_back(static_cast<BufferType>(n.y()));
+    buffer.push_back(static_cast<BufferType>(n.z()));
   }
 
   ///adds `acolor` RGB components to `buffer`
-  static void add_color_in_buffer(const CGAL::IO::Color& acolor, std::vector<float>& buffer)
+  static void add_color_in_buffer(const CGAL::IO::Color& acolor, std::vector<BufferType>& buffer)
   {
-    buffer.push_back((float)acolor.red()/(float)255);
-    buffer.push_back((float)acolor.green()/(float)255);
-    buffer.push_back((float)acolor.blue()/(float)255);
+    buffer.push_back((BufferType)acolor.red()/(BufferType)255);
+    buffer.push_back((BufferType)acolor.green()/(BufferType)255);
+    buffer.push_back((BufferType)acolor.blue()/(BufferType)255);
   }
 
   /// @return true iff the points of 'facet' form a convex face
@@ -738,61 +768,20 @@ protected:
         { cdt.insert_constraint(previous, first); }
       }
 
-      // (2) We mark all external triangles
-      // (2.1) We initialize is_external and is_process values
+      // (2.1) We initialize nesting_level
       for(typename CDT::All_faces_iterator fit = cdt.all_faces_begin(),
             fitend = cdt.all_faces_end(); fit!=fitend; ++fit)
-      {
-        fit->info().is_external = true;
-        fit->info().is_process = false;
-      }
-      // (2.2) We check if the facet is external or internal
-      std::queue<typename CDT::Face_handle> face_queue;
-      typename CDT::Face_handle face_internal = nullptr;
-      if (cdt.infinite_vertex()->face()!=nullptr)
-      { face_queue.push(cdt.infinite_vertex()->face()); }
-      while(!face_queue.empty())
-      {
-        typename CDT::Face_handle fh = face_queue.front();
-        face_queue.pop();
-        if(!fh->info().is_process)
-        {
-          fh->info().is_process = true;
-          for(int i=0; i<3; ++i)
-          {
-            if(!cdt.is_constrained(std::make_pair(fh, i)))
-            {
-              if (fh->neighbor(i)!=nullptr)
-              { face_queue.push(fh->neighbor(i)); }
-            }
-            else if (face_internal==nullptr)
-            {
-              face_internal = fh->neighbor(i);
-            }
-          }
-        }
-      }
+      { fit->info().m_nesting_level=-1; }
 
-      if ( face_internal!=nullptr )
-      { face_queue.push(face_internal); }
-
-      while(!face_queue.empty())
+      std::queue<typename CDT::Edge> border;
+      internal::mark_domains(cdt, cdt.infinite_face(), 0, border);
+      while(!border.empty())
       {
-        typename CDT::Face_handle fh = face_queue.front();
-        face_queue.pop();
-        if(!fh->info().is_process)
-        {
-          fh->info().is_process = true;
-          fh->info().is_external = false;
-          for(unsigned int i=0; i<3; ++i)
-          {
-            if(!cdt.is_constrained(std::make_pair(fh, i)))
-            {
-              if (fh->neighbor(i)!=nullptr)
-              { face_queue.push(fh->neighbor(i)); }
-            }
-          }
-        }
+        auto e=border.front();
+        border.pop();
+        auto n=e.first->neighbor(e.second);
+        if (n->info().m_nesting_level==-1)
+        { internal::mark_domains(cdt, n, e.first->info().m_nesting_level+1, border); }
       }
 
       // (3) Now we iterates on the internal faces to add the vertices
@@ -800,7 +789,7 @@ protected:
       for(typename CDT::Finite_faces_iterator ffit=cdt.finite_faces_begin(),
             ffitend = cdt.finite_faces_end(); ffit!=ffitend; ++ffit)
       {
-        if(!ffit->info().is_external)
+        if(ffit->info().in_domain())
         {
           for(unsigned int i=0; i<3; ++i)
           {
@@ -882,9 +871,8 @@ protected:
 
   struct Face_info
   {
-    bool exist_edge[3];
-    bool is_external;
-    bool is_process;
+    int m_nesting_level=-1;
+    bool in_domain() { return m_nesting_level%2==1; }
   };
 
   typedef CGAL::Projection_traits_3<CGAL::Exact_predicates_inexact_constructions_kernel> P_traits;
@@ -899,8 +887,8 @@ protected:
   std::vector<BufferType>* m_pos_buffer;
   std::vector<IndexType>* m_index_buffer;
   std::vector<BufferType>* m_color_buffer;
-  std::vector<BufferType>* m_flat_normal_buffer;
-  std::vector<BufferType>* m_gouraud_normal_buffer;
+  mutable std::vector<BufferType>* m_flat_normal_buffer;
+  mutable std::vector<BufferType>* m_gouraud_normal_buffer;
 
   CGAL::Bbox_3* m_bb;
 
@@ -908,7 +896,7 @@ protected:
   bool m_zero_y; /// True iff all points have y==0
   bool m_zero_z; /// True iff all points have z==0
 
-  bool m_inverse_normal;
+  mutable bool m_inverse_normal;
 
   // Local variables, used when we started a new face.g
   bool m_face_started;
@@ -923,5 +911,5 @@ protected:
 
 } // End namespace CGAL
 
-#endif // CGAL_VBO_BUFFER_FILLER_H
+#endif // CGAL_BUFFER_FOR_VAO_H
 
