@@ -20,7 +20,7 @@
  *   It is very important that the BigFloats used in these intervals
  *   have no error at the beginning, and this is maintained
  *   by refinement.  Note that if x, y are error-free BigFloats,
- *   then (x+y)/2 may not be error-free (in current implementaion.
+ *   then (x+y)/2 may not be error-free (in current implementation.
  *   We have to call a special "exact divide by 2" method,
  *   (x+y).div2() for this purpose.
  *
@@ -38,11 +38,11 @@
  *  Author:  Chee Yap and Sylvain Pion, Vikram Sharma
  *  Date:    July 20, 2002
  *
- * WWW URL: http://cs.nyu.edu/exact/
+ * WWW URL: https://cs.nyu.edu/exact/
  * Email: exact@cs.nyu.edu
  *
- * $URL: https://github.com/CGAL/cgal/blob/v5.4/CGAL_Core/include/CGAL/CORE/poly/Sturm.h $
- * $Id: Sturm.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+ * $URL: https://github.com/CGAL/cgal/blob/v6.0.1/CGAL_Core/include/CGAL/CORE/poly/Sturm.h $
+ * $Id: include/CGAL/CORE/poly/Sturm.h 50cfbde3b84 $
  * SPDX-License-Identifier: LGPL-3.0-or-later
  ***************************************************************************/
 
@@ -608,8 +608,7 @@ public:
       if (ff == 0) {
         NEWTON_DIV_BY_ZERO = true;
         del = 0;
-        core_error("Zero divisor in Newton Iteration",
-                __FILE__, __LINE__, false);
+        CGAL_CORE_warning_msg(false, "Zero divisor in Newton Iteration");
         return 0;
       }
 
@@ -681,8 +680,7 @@ public:
       stepsize++; // heuristic
     } while ((del != 0) && ((del.uMSB() >= -prec) && (count >0))) ;
 
-    if (count == 0) core_error("newtonIterE: reached count=0",
-                            __FILE__, __LINE__, true);
+    CGAL_assertion_msg(count != 0, "newtonIterE: reached count=0");
     del = BigFloat(core_abs(del.m()), err, del.exp() );
     del.makeCeilExact();
     return val;
@@ -1132,3 +1130,4 @@ CORE_INLINE void testNewtonSturm(const Polynomial<NT>&P, int prec, int n = -1) {
 } //namespace CORE
 
 #endif
+
