@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Surface_mesher/include/CGAL/IO/Complex_2_in_triangulation_3_file_writer.h $
-// $Id: Complex_2_in_triangulation_3_file_writer.h 580a1ef 2020-05-22T15:31:50+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesher/include/CGAL/IO/Complex_2_in_triangulation_3_file_writer.h $
+// $Id: include/CGAL/IO/Complex_2_in_triangulation_3_file_writer.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,6 +16,11 @@
 
 #include <CGAL/license/Surface_mesher.h>
 
+#define CGAL_DEPRECATED_HEADER "<CGAL/IO/Complex_2_in_triangulation_3_file_writer.h>"
+#define CGAL_DEPRECATED_MESSAGE_DETAILS \
+  "The 3D Mesh Generation package (see https://doc.cgal.org/latest/Mesh_3/) should be used instead."
+#include <CGAL/Installation/internal/deprecation_warning.h>
+
 #include <CGAL/disable_warnings.h>
 
 #define CGAL_C2T3_USE_FILE_WRITER_OFF
@@ -540,3 +545,4 @@ output_interior_facets_to_off (std::ostream& os, const Tr & T) {
 #include <CGAL/enable_warnings.h>
 
 #endif  // CGAL_IO_COMPLEX_2_IN_TRIANGULATION_3_FILE_WRITER_H
+
