@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Mesh_3/include/CGAL/Mesh_3/Sliver_perturber.h $
-// $Id: Sliver_perturber.h 590ddf8 2021-10-08T15:38:47+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Mesh_3/include/CGAL/Mesh_3/Sliver_perturber.h $
+// $Id: include/CGAL/Mesh_3/Sliver_perturber.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -58,16 +58,8 @@
 #endif
 
 #include <boost/format.hpp>
-#ifdef CGAL_MESH_3_USE_RELAXED_HEAP
-#  error This option CGAL_MESH_3_USE_RELAXED_HEAP is no longer supported
-// The reason is that the Boost relaxed heap does not ensure a strict order
-// of the priority queue.
-#include <boost/pending/relaxed_heap.hpp>
-#else
 #include <CGAL/Modifiable_priority_queue.h>
-#endif //CGAL_MESH_3_USE_RELAXED_HEAP
 #include <boost/ptr_container/ptr_vector.hpp>
-#include <boost/type_traits/is_convertible.hpp>
 
 #include <boost/unordered_map.hpp>
 
@@ -79,7 +71,7 @@ namespace Mesh_3 {
 
 /**
 * @class PVertex
-* Vertex with associated perturbation datas
+* Vertex with associated perturbation data
 */
 // Sequential
 template< typename FT
@@ -179,7 +171,7 @@ void update_saved_erase_counter() {}
 bool is_zombie() { return false; }
 
 private:
-/// Private datas
+/// Private data
 Vertex_handle vertex_handle_;
 unsigned int incident_sliver_nb_;
 FT min_value_;
@@ -302,7 +294,7 @@ bool operator<(const Self& pv) const
 }
 
 private:
-/// Private datas
+/// Private data
 Vertex_handle vertex_handle_;
 unsigned int vh_erase_counter_when_added_;
 int in_dimension_;
@@ -325,8 +317,8 @@ class Sliver_perturber_base
 {
 protected:
   typedef typename Tr::Vertex_handle                        Vertex_handle;
-  typedef typename Tr::Geom_traits                          Gt;
-  typedef typename Gt::FT                                   FT;
+  typedef typename Tr::Geom_traits                          GT;
+  typedef typename GT::FT                                   FT;
   typedef typename std::vector<Vertex_handle>               Bad_vertices_vector;
   typedef typename Tr::Lock_data_structure                  Lock_data_structure;
 
@@ -353,8 +345,8 @@ class Sliver_perturber_base<Tr, Parallel_tag>
 {
 protected:
   typedef typename Tr::Vertex_handle                        Vertex_handle;
-  typedef typename Tr::Geom_traits                          Gt;
-  typedef typename Gt::FT                                   FT;
+  typedef typename Tr::Geom_traits                          GT;
+  typedef typename GT::FT                                   FT;
   typedef typename tbb::concurrent_vector<Vertex_handle>    Bad_vertices_vector;
   typedef typename Tr::Lock_data_structure                  Lock_data_structure;
 
@@ -445,7 +437,7 @@ class Sliver_perturber
     typename C3T3::Triangulation, Concurrency_tag>                      Base;
 
   typedef typename C3T3::Triangulation          Tr;
-  typedef typename Tr::Geom_traits              Gt;
+  typedef typename Tr::Geom_traits              GT;
 
   typedef typename Tr::Cell_handle              Cell_handle;
   typedef typename Base::Vertex_handle          Vertex_handle;
@@ -458,7 +450,7 @@ class Sliver_perturber
   typedef typename std::vector<Vertex_handle>   Vertex_vector;
   typedef typename Base::Bad_vertices_vector    Bad_vertices_vector;
 
-  typedef typename Gt::FT                       FT;
+  typedef typename GT::FT                       FT;
 
   // Helper
   typedef class C3T3_helpers<C3T3,MeshDomain> C3T3_helpers;
@@ -508,11 +500,8 @@ private:
   };
 
   typedef std::less<PVertex> less_PVertex;
-  #ifdef CGAL_MESH_3_USE_RELAXED_HEAP
-  typedef boost::relaxed_heap<PVertex, less_PVertex, PVertex_id> PQueue;
-  #else
-  typedef ::CGAL::internal::mutable_queue_with_remove<PVertex,std::vector<PVertex>, less_PVertex, PVertex_id> PQueue;
-  #endif //CGAL_MESH_3_USE_RELAXED_HEAP
+  typedef Modifiable_priority_queue<PVertex, less_PVertex, PVertex_id> PQueue;
+
 
 public:
   /**
@@ -564,7 +553,7 @@ private:
   int build_priority_queue(const FT& sliver_bound, PQueue& pqueue) const;
 
   /**
-   * Updates priority queue for all vertices of \c vertices
+   * Updates priority queue for all vertices of `vertices`.
    */
   // Sequential
   int update_priority_queue(const Vertex_vector& vertices,
@@ -579,7 +568,7 @@ private:
 #endif
 
   /**
-   * Updates \c pv in priority queue
+   * Updates `pv` in priority queue.
    */
   int update_priority_queue(const PVertex& pv, PQueue& pqueue) const;
 
@@ -593,7 +582,7 @@ private:
                 ) const;
 
   /**
-   * Returns a pvertex from a vertex handle \c vh, using id \c pv_id
+   * Returns a pvertex from a vertex handle `vh`, using the id `pv_id`.
    */
   PVertex
   make_pvertex(const Vertex_handle& vh,
@@ -606,13 +595,13 @@ private:
                const typename PVertex::id_type& pv_id) const;
 
   /**
-   * Updates a pvertex \c pv
+   * Updates a pvertex `pv`.
    */
   void update_pvertex(PVertex& pv, const FT& sliver_bound) const;
   void update_pvertex__concurrent(PVertex& pv, const FT& sliver_bound) const;
 
   /**
-   * Returns \c vh pvertex id
+   * Returns `vh` pvertex id.
    */
   typename PVertex::id_type get_pvertex_id(const Vertex_handle& vh) const
   {
@@ -620,7 +609,7 @@ private:
   }
 
   /**
-   * Update bad vertices vector, wrt \c sliver_bound
+   * Updates bad vertices vector, wrt. `sliver_bound`.
    */
   // Sequential
   void update_bad_vertices(std::vector<Vertex_handle> &bad_vertices,
@@ -828,7 +817,7 @@ operator()(Visitor visitor)
 #endif
 
   running_time_.stop();
-  helper_.reset_cache();//in case we re-use caches in another operation
+  helper_.reset_cache();//in case we reuse caches in another operation
                                // after this perturbation
 
 #ifdef CGAL_MESH_3_PERTURBER_VERBOSE
@@ -867,16 +856,7 @@ operator()(Visitor visitor)
 
 #if defined(CGAL_MESH_3_EXPORT_PERFORMANCE_DATA) \
  && defined(CGAL_MESH_3_PROFILING)
-  if (ret == BOUND_REACHED)
-  {
-    CGAL_MESH_3_SET_PERFORMANCE_DATA("Perturber_optim_time", perturbation_time);
-  }
-  else
-  {
-    CGAL_MESH_3_SET_PERFORMANCE_DATA("Perturber_optim_time",
-      (ret == CANT_IMPROVE_ANYMORE ?
-      "CANT_IMPROVE_ANYMORE" : "TIME_LIMIT_REACHED"));
-  }
+  CGAL_MESH_3_SET_PERFORMANCE_DATA("Perturber_optim_time", perturbation_time);
 #endif
 
   return ret;
@@ -939,14 +919,13 @@ perturb(const FT& sliver_bound, PQueue& pqueue, Visitor& visitor) const
 
 #ifdef CGAL_LINKED_WITH_TBB
   // Parallel
-  if (boost::is_convertible<Concurrency_tag, Parallel_tag>::value)
+  if (std::is_convertible<Concurrency_tag, Parallel_tag>::value)
   {
     this->create_task_group();
 
-    while (pqueue.size() > 0)
+    while (!pqueue.empty())
     {
-      PVertex pv = pqueue.top();
-      pqueue.pop();
+      PVertex pv = pqueue.top_and_pop();
       enqueue_task(pv, sliver_bound,
                    visitor, bad_vertices);
     }
@@ -978,8 +957,7 @@ perturb(const FT& sliver_bound, PQueue& pqueue, Visitor& visitor) const
     while ( !is_time_limit_reached() && !pqueue.empty() )
     {
       // Get pqueue head
-      PVertex pv = pqueue.top();
-      pqueue.pop();
+      PVertex pv = pqueue.top_and_pop();
       --pqueue_size;
 
       CGAL_assertion(pv.is_perturbable());
@@ -1045,7 +1023,7 @@ perturb(const FT& sliver_bound, PQueue& pqueue, Visitor& visitor) const
         }
       }
 
-      // Update pqueue in every cases, because pv was poped
+      // Update pqueue in every cases, because pv was popped
       pqueue_size += update_priority_queue(pv, pqueue);
       visitor.end_of_perturbation_iteration(pqueue_size);
 
@@ -1246,7 +1224,7 @@ update_priority_queue(const PVertex& pv, PQueue& pqueue) const
     }
     else
     {
-      pqueue.remove(pv);
+      pqueue.erase(pv);
       return -1;
     }
   }
@@ -1274,7 +1252,7 @@ perturb_vertex( PVertex pv
               , bool *could_lock_zone
               ) const
 {
-  typename Gt::Construct_point_3 cp = tr_.geom_traits().construct_point_3_object();
+  typename GT::Construct_point_3 cp = tr_.geom_traits().construct_point_3_object();
 
 #ifdef CGAL_CONCURRENT_MESH_3_PROFILING
   static Profile_branch_counter_3 bcounter(
@@ -1391,7 +1369,7 @@ perturb_vertex( PVertex pv
       ++bcounter;
 #endif
 
-      // Update pqueue in every cases, because pv was poped
+      // Update pqueue in every cases, because pv was popped
       if (pv.is_perturbable())
       {
         enqueue_task(pv, sliver_bound, visitor, bad_vertices);
@@ -1646,3 +1624,4 @@ enqueue_task(const PVertex &pv,
 #include <CGAL/enable_warnings.h>
 
 #endif // CGAL_MESH_3_SLIVERS_PERTURBER_H
+
