@@ -5,8 +5,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Number_types/include/CGAL/Mpzf.h $
-// $Id: Mpzf.h f3d0d76 2022-10-06T15:35:41+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Number_types/include/CGAL/Mpzf.h $
+// $Id: include/CGAL/Mpzf.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)        :  Marc Glisse
@@ -24,6 +24,7 @@
 #include <vector>
 #include <math.h>
 #include <cmath>
+#include <cstdint>
 #include <iostream>
 #include <stdexcept>
 #ifdef CGAL_USE_GMPXX
@@ -149,7 +150,7 @@ template <class T, class = void> struct pool2 {
   static bool empty() { return data() == 0; }
   static const int extra = 1; // TODO: handle the case where a pointer is larger than a mp_limb_t
   private:
-  CGAL_static_assertion(sizeof(T) >= sizeof(T*));
+  static_assert(sizeof(T) >= sizeof(T*));
   static T& data () {
     static CGAL_MPZF_TLS T data_ = 0;
     return data_;
@@ -163,12 +164,12 @@ template <class T, class = void> struct pool3 {
   static bool empty() { return data() == 0; }
   static const int extra = 1; // TODO: handle the case where a pointer is larger than a mp_limb_t
   private:
-  CGAL_static_assertion(sizeof(T) >= sizeof(T*));
+  static_assert(sizeof(T) >= sizeof(T*));
   struct cleaner {
     T data_ = 0;
     ~cleaner(){
       // Deallocate everything. As an alternative, we could store it in a
-      // global location, for re-use by a later thread.
+      // global location, for reuse by a later thread.
       while (!empty())
         delete[] (pop() - (extra + 1));
     }
@@ -189,7 +190,7 @@ template <class T, class = void> struct no_pool {
 };
 
 // Only used with an argument known not to be 0.
-inline int ctz (boost::uint64_t x) {
+inline int ctz (std::uint64_t x) {
 #if defined(_MSC_VER)
   unsigned long ret;
   _BitScanForward64(&ret, x);
@@ -201,7 +202,7 @@ inline int ctz (boost::uint64_t x) {
   return __builtin_ctzll (x);
 #endif
 }
-inline int clz (boost::uint64_t x) {
+inline int clz (std::uint64_t x) {
 #if defined(_MSC_VER)
   unsigned long ret;
   _BitScanReverse64(&ret, x);
@@ -431,7 +432,7 @@ struct Mpzf {
   }
   Mpzf(double d){
     init();
-    using boost::uint64_t;
+    using std::uint64_t;
     union {
 #ifdef CGAL_LITTLE_ENDIAN
       struct { uint64_t man:52; uint64_t exp:11; uint64_t sig:1; } s;
@@ -456,7 +457,7 @@ struct Mpzf {
     }
     int e1 = (int)dexp+13;
     // FIXME: make it more general! But not slower...
-    CGAL_static_assertion(GMP_NUMB_BITS == 64);
+    static_assert(GMP_NUMB_BITS == 64);
     int e2 = e1 % 64;
     exp = e1 / 64 - 17;
     // 52+1023+13==17*64 ?
