@@ -4,13 +4,18 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Partition_2/include/CGAL/Partition_2/Vertex_visibility_graph_2_impl.h $
-// $Id: Vertex_visibility_graph_2_impl.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Partition_2/include/CGAL/Partition_2/Vertex_visibility_graph_2_impl.h $
+// $Id: include/CGAL/Partition_2/Vertex_visibility_graph_2_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Susan Hert <hert@mpi-sb.mpg.de>
 
+#ifndef CGAL_PARTITION_2_VERTEX_VISIBILITY_GRAPH_2_IMPL_H
+#define CGAL_PARTITION_2_VERTEX_VISIBILITY_GRAPH_2_IMPL_H
+
+#include <CGAL/license/Partition_2.h>
+
 namespace CGAL {
 
 
@@ -701,3 +706,5 @@ void Vertex_visibility_graph_2<Traits>::handle(Tree_iterator p,
 
 }
 
+#endif // CGAL_PARTITION_2_VERTEX_VISIBILITY_GRAPH_2_IMPL_H
+
