@@ -8,8 +8,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Polygon/include/CGAL/Polygon_2/Polygon_2_algorithms_impl.h $
-// $Id: Polygon_2_algorithms_impl.h 6b87fe3 2020-12-05T11:11:33+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon/include/CGAL/Polygon_2/Polygon_2_algorithms_impl.h $
+// $Id: include/CGAL/Polygon_2/Polygon_2_algorithms_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -167,7 +167,7 @@ ForwardIterator left_vertex_2(ForwardIterator first,
                                    ForwardIterator last,
                                    const PolygonTraits&traits)
 {
-    CGAL_polygon_precondition(first != last);
+    CGAL_precondition(first != last);
     internal::Polygon_2::Compare_vertices<PolygonTraits>
         less(traits.less_xy_2_object());
     return std::min_element(first, last, less);
@@ -183,7 +183,7 @@ ForwardIterator right_vertex_2(ForwardIterator first,
                                     ForwardIterator last,
                                     const PolygonTraits &traits)
 {
-    CGAL_polygon_precondition(first != last);
+    CGAL_precondition(first != last);
     internal::Polygon_2::Compare_vertices<PolygonTraits>
         less(traits.less_xy_2_object());
     return std::max_element(first, last, less);
@@ -199,7 +199,7 @@ ForwardIterator top_vertex_2(ForwardIterator first,
                                   ForwardIterator last,
                                   const PolygonTraits&traits)
 {
-    CGAL_polygon_precondition(first != last);
+    CGAL_precondition(first != last);
     return std::max_element(first, last, traits.less_yx_2_object());
 }
 
@@ -213,7 +213,7 @@ ForwardIterator bottom_vertex_2(ForwardIterator first,
                                      ForwardIterator last,
                                      const PolygonTraits&traits)
 {
-    CGAL_polygon_precondition(first != last);
+    CGAL_precondition(first != last);
     return std::min_element(first, last, traits.less_yx_2_object());
 }
 
@@ -326,7 +326,7 @@ Oriented_side oriented_side_2(ForwardIterator first,
                                         const Traits& traits)
 {
   Orientation o = orientation_2(first, last, traits);
-  CGAL_polygon_assertion(o != COLLINEAR);
+  CGAL_assertion(o != COLLINEAR);
 
   Bounded_side b = bounded_side_2(first, last, point, traits);
   switch (b) {
@@ -370,7 +370,7 @@ int which_side_in_slab(Point const &point, Point const &low, Point const &high,
 // precondition: low.y < point.y < high.y
 {
     // first we try to decide on x coordinate values alone
-    // This is an optimisation (whether this is really faster for
+    // This is an optimization (whether this is really faster for
     // a homogeneous kernel is not clear, as comparisons can be expensive.
     Comparison_result low_x_comp_res = compare_x_2(point, low);
     Comparison_result high_x_comp_res = compare_x_2(point, high);
@@ -503,13 +503,17 @@ Bounded_side bounded_side_2(ForwardIterator first,
 // uses Traits::Less_xy_2 (used by left_vertex_2)
 //      Traits::orientation_2_object()
 
-template <class ForwardIterator, class Traits>
-Orientation orientation_2(ForwardIterator first,
-                                    ForwardIterator last,
-                                    const Traits& traits)
-{
-  CGAL_polygon_precondition(is_simple_2(first, last, traits));
+namespace Polygon {
+namespace internal {
 
+// This exists because the "is_simple_2" precondition in the orientation_2() function is in fact
+// stronger than necessary: it also works for strictly simple polygons, which matters for
+// Straight line skeletons, as the offset polygons might have non-manifoldness.
+template <class ForwardIterator, class Traits>
+Orientation orientation_2_no_precondition(ForwardIterator first,
+                                          ForwardIterator last,
+                                          const Traits& traits)
+{
   ForwardIterator i = left_vertex_2(first, last, traits);
 
   ForwardIterator prev = (i == first) ? last : i;
@@ -528,6 +532,18 @@ Orientation orientation_2(ForwardIterator first,
   return traits.orientation_2_object()(Point(*prev), Point(*i), Point(*next));
 }
 
+} // namespace internal
+} // namespace Polygon
+
+template <class ForwardIterator, class Traits>
+Orientation orientation_2(ForwardIterator first,
+                          ForwardIterator last,
+                          const Traits& traits)
+{
+  CGAL_precondition(is_simple_2(first, last, traits));
+  return Polygon::internal::orientation_2_no_precondition(first, last, traits);
+}
+
 } //namespace CGAL
 
 /// \endcond
@@ -535,3 +551,4 @@ Orientation orientation_2(ForwardIterator first,
 // Local Variables:
 // c-basic-offset: 4
 // End:
+
