@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Triangulation_3/include/CGAL/Robust_weighted_circumcenter_filtered_traits_3.h $
-// $Id: Robust_weighted_circumcenter_filtered_traits_3.h c32b1f4 2022-11-16T13:22:39+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Triangulation_3/include/CGAL/Robust_weighted_circumcenter_filtered_traits_3.h $
+// $Id: include/CGAL/Robust_weighted_circumcenter_filtered_traits_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,6 +18,7 @@
 #include <CGAL/number_utils_classes.h>
 #include <CGAL/Cartesian_converter.h>
 #include <CGAL/Exact_predicates_exact_constructions_kernel.h>
+#include <CGAL/Triangulation_structural_filtering_traits.h>
 #include <CGAL/constructions/kernel_ftC3.h>
 
 namespace CGAL {
@@ -531,6 +532,13 @@ public:
   Robust_circumcenter_filtered_traits_3(const Kernel& k = Kernel()) : Kernel(k) { }
 };
 
+
+template < class BaseGt >
+struct Triangulation_structural_filtering_traits<Robust_circumcenter_filtered_traits_3<BaseGt> > {
+    typedef typename Triangulation_structural_filtering_traits<BaseGt>::Use_structural_filtering_tag  Use_structural_filtering_tag;
+};
+
+
 template<class K_>
 class Robust_weighted_circumcenter_filtered_traits_3
   : public Robust_circumcenter_filtered_traits_3<K_>
