@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Snap_rounding_2/include/CGAL/Snap_rounding_kd_2.h $
-// $Id: Snap_rounding_kd_2.h c5207cb 2022-11-24T09:54:56+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Snap_rounding_2/include/CGAL/Snap_rounding_kd_2.h $
+// $Id: include/CGAL/Snap_rounding_kd_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -27,8 +27,6 @@
 #include <CGAL/Dimension.h>
 #include <CGAL/number_type_config.h>
 
-#include <boost/type_traits/is_pointer.hpp>
-
 #include <CGAL/Kd_tree.h>
 #include <CGAL/Search_traits_2.h>
 #include <CGAL/Fuzzy_iso_box.h>
@@ -71,7 +69,7 @@ public:
 //////////////////////
 //Search_traits_kd_tree_2
 //
-//(Search traits modified to be used by the Spacial Searching kd_trees for Snap rounding)
+//(Search traits modified to be used by the Spatial Searching kd_trees for Snap rounding)
 //////////////////////
 
 template < class Traits_, class Point_ = typename Traits_::Point_2 >
@@ -108,7 +106,7 @@ public:
 
 template<class Traits_, class SAVED_OBJECT>
 class Multiple_kd_tree {
-  CGAL_static_assertion_msg((boost::is_pointer<SAVED_OBJECT>::value), "SAVED_OBJECT is not a pointer.");
+  static_assert(std::is_pointer<SAVED_OBJECT>::value, "SAVED_OBJECT is not a pointer.");
 private:
   typedef Traits_                                       Traits;
   typedef typename Traits::FT                           NT;
