@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Surface_mesh_topology/include/CGAL/Surface_mesh_topology/internal/Shortest_noncontractible_cycle.h $
-// $Id: Shortest_noncontractible_cycle.h 52186a0 2020-05-14T11:38:15+02:00 Guillaume Damiand
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesh_topology/include/CGAL/Surface_mesh_topology/internal/Shortest_noncontractible_cycle.h $
+// $Id: include/CGAL/Surface_mesh_topology/internal/Shortest_noncontractible_cycle.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Thien Hoang <thienvhoang99@gmail.com>
@@ -32,16 +32,16 @@ namespace internal {
 template<class SNC, bool Copy>
 struct Get_original_dart
 {
-  static typename SNC::Original_dart_const_handle
-  run(SNC* snc, typename SNC::Dart_handle dh)
+  static typename SNC::Original_dart_const_descriptor
+  run(SNC* snc, typename SNC::Dart_descriptor dh)
   { return snc->m_copy_to_origin[dh]; }
 };
 
 template<class SNC>
 struct Get_original_dart<SNC, false>
 {
-  static typename SNC::Original_dart_const_handle
-  run(SNC* /* snc */, typename SNC::Dart_handle dh)
+  static typename SNC::Original_dart_const_descriptor
+  run(SNC* /* snc */, typename SNC::Dart_descriptor dh)
   { return dh; }
 };
 
@@ -55,19 +55,19 @@ public:
   friend struct Get_original_dart<Self, Copy>;
 
   using Original_map_wrapper=internal::Generic_map_selector<Mesh, Items_for_shortest_noncontractible_cycle>;
-  using Original_dart_const_handle=typename Original_map_wrapper::Dart_const_handle_original;
+  using Original_dart_const_descriptor=typename Original_map_wrapper::Dart_const_descriptor_original;
 
   using Local_map        =typename Original_map_wrapper::Generic_map;
-  using Dart_handle      =typename Local_map::Dart_handle;
-  using Dart_const_handle=typename Local_map::Dart_const_handle;
+  using Dart_descriptor      =typename Local_map::Dart_descriptor;
+  using Dart_const_descriptor=typename Local_map::Dart_const_descriptor;
   using size_type        = typename Local_map::size_type;
 
-  using Dart_container=std::vector<Dart_handle>;
+  using Dart_container=std::vector<Dart_descriptor>;
   using Path          =CGAL::Surface_mesh_topology::Path_on_surface<Mesh>;
 
   // Associations between original darts and their copy.
-  using Origin_to_copy=boost::unordered_map<Original_dart_const_handle, Dart_handle>;
-  using Copy_to_origin=boost::unordered_map<Dart_handle, Original_dart_const_handle>;
+  using Origin_to_copy=std::unordered_map<Original_dart_const_descriptor, Dart_descriptor>;
+  using Copy_to_origin=std::unordered_map<Dart_descriptor, Original_dart_const_descriptor>;
 
   /// @return the local map
   const Local_map& get_local_map() const
@@ -125,7 +125,7 @@ public:
   }
 
   template <class WeightFunctor>
-  Path compute_cycle(Original_dart_const_handle root_vertex,
+  Path compute_cycle(Original_dart_const_descriptor root_vertex,
                      typename WeightFunctor::Weight_t* length,
                      const WeightFunctor& wf,
                      bool display_time=false)
@@ -135,7 +135,7 @@ public:
     { t.start(); }
 
     m_cycle.clear();
-    Dart_handle root=m_origin_to_copy[root_vertex];
+    Dart_descriptor root=m_origin_to_copy[root_vertex];
     this->compute_cycle(root, m_cycle, length, nullptr, wf);
 
     if (display_time)
@@ -148,13 +148,13 @@ public:
   }
 
   template <class WeightFunctor=Unit_weight_functor>
-  Path compute_cycle(Original_dart_const_handle root_vertex,
+  Path compute_cycle(Original_dart_const_descriptor root_vertex,
                      typename WeightFunctor::Weight_t* length,
                      bool display_time=false)
   { return compute_cycle(root_vertex, length, WeightFunctor(), display_time); }
 
   template <class WeightFunctor=Unit_weight_functor>
-  Path compute_cycle(Original_dart_const_handle root_vertex,
+  Path compute_cycle(Original_dart_const_descriptor root_vertex,
                      bool display_time=false)
   { return compute_cycle(root_vertex, nullptr, display_time); }
 
@@ -173,7 +173,7 @@ public:
     for (auto it=get_local_map().template attributes<0>().begin(),
          itend=get_local_map().template attributes<0>().end(); it!=itend; ++it)
     {
-      Dart_handle dh=get_local_map().template dart_of_attribute<0>(it);
+      Dart_descriptor dh=get_local_map().template dart_of_attribute<0>(it);
       typename WeightFunctor::Weight_t temp_length;
       if (first_check)
       {
@@ -209,9 +209,9 @@ public:
   { return compute_shortest_non_contractible_cycle(nullptr, display_time); }
 
 protected:
-  int vertex_info(Dart_handle dh) const
+  int vertex_info(Dart_descriptor dh) const
   { return get_local_map().template info<0>(dh); }
-  int& vertex_info(Dart_handle dh)
+  int& vertex_info(Dart_descriptor dh)
   { return get_local_map().template info<0>(dh); }
 
   void create_vertex_info()
@@ -233,7 +233,7 @@ protected:
   }
 
   template <class WeightFunctor, class Distance_>
-  void compute_spanning_tree(Dart_handle root, Dart_container& spanning_tree,
+  void compute_spanning_tree(Dart_descriptor root, Dart_container& spanning_tree,
                              std::vector<Distance_>& distance_from_root,
                              std::vector<int>& trace_index,
                              const WeightFunctor& wf)
@@ -258,7 +258,7 @@ protected:
 
   /// Create a spanning tree using Dijkstra
   template <class WeightFunctor, class Distance_>
-  void compute_Dijkstra_tree(Dart_handle root, Dart_container& spanning_tree,
+  void compute_Dijkstra_tree(Dart_descriptor root, Dart_container& spanning_tree,
                              std::vector<Distance_>& distance_from_root,
                              std::vector<int>& trace_index,
                              const WeightFunctor& wf)
@@ -267,10 +267,10 @@ protected:
     Dijkstra_comparator<Distance_> dc(distance_from_root);
     //std::priority_queue<int, std::vector<int>, Dijkstra_comparator<Distance_> > pq(dc);
     typedef boost::heap::fibonacci_heap<int, boost::heap::compare<Dijkstra_comparator<Distance_>>> Heap;
-    typedef typename Heap::handle_type heap_handle;
+    typedef typename Heap::handle_type heap_descriptor;
 
     Heap pq(dc);
-    std::unordered_map<int, heap_handle> inqueue;
+    std::unordered_map<int, heap_descriptor> inqueue;
 
     int vertex_index=0;
     size_type vertex_visited=get_local_map().get_new_mark();
@@ -288,12 +288,12 @@ protected:
 
       inqueue.erase(u_index);
 
-      Dart_handle u=(u_index==0)?root:get_local_map().next(spanning_tree[u_index-1]);
+      Dart_descriptor u=(u_index==0)?root:get_local_map().next(spanning_tree[u_index-1]);
       CGAL_assertion(u_index==vertex_info(u));
-      Dart_handle it=u;
+      Dart_descriptor it=u;
       do
       {
-        Dart_handle v=get_local_map().next(it);
+        Dart_descriptor v=get_local_map().next(it);
         Distance_ w=wf(Get_original_dart<Self, Copy>::run(this, nonhole_dart_of_same_edge(it)));
         if (!get_local_map().is_marked(v, vertex_visited))
         {
@@ -334,7 +334,7 @@ protected:
 
   /// Create a spanning tree using BFS
   template <class Distance_>
-  void compute_BFS_tree(Dart_handle root, Dart_container& spanning_tree,
+  void compute_BFS_tree(Dart_descriptor root, Dart_container& spanning_tree,
                         std::vector<Distance_>& distance_from_root,
                         std::vector<int>& trace_index)
   {
@@ -352,12 +352,12 @@ protected:
     {
       int u_index=q.front();
       q.pop();
-      Dart_handle u=(u_index==0)?root:get_local_map().next(spanning_tree[u_index-1]);
+      Dart_descriptor u=(u_index==0)?root:get_local_map().next(spanning_tree[u_index-1]);
       CGAL_assertion(u_index==vertex_info(u));
-      Dart_handle it=u;
+      Dart_descriptor it=u;
       do
       {
-        Dart_handle v=get_local_map().next(it);
+        Dart_descriptor v=get_local_map().next(it);
         if (!get_local_map().is_marked(v, vertex_visited))
         {
           int v_index=++vertex_index;
@@ -380,10 +380,10 @@ protected:
 
   /// Check if there is only one unmarked edge around a face.
   /// If there is, let dh_only_edge=the edge separating it and its only adjacent face.
-  bool is_degree_one_face(Dart_handle dh_face, Dart_handle& dh_only_edge,
+  bool is_degree_one_face(Dart_descriptor dh_face, Dart_descriptor& dh_only_edge,
                           size_type edge_deleted)
   {
-    Dart_handle dh=dh_face;
+    Dart_descriptor dh=dh_face;
     dh_only_edge=nullptr;
     do
     {
@@ -412,7 +412,7 @@ protected:
       if (!get_local_map().is_marked(dh, edge_deleted))
       { get_local_map().template mark_cell<1>(dh, edge_deleted); }
     }
-    std::queue<Dart_handle> degree_one_faces;
+    std::queue<Dart_descriptor> degree_one_faces;
     // Add to queue the degree-1 faces
     for (auto it=get_local_map().darts().begin(), itend=get_local_map().darts().end();
          it!=itend; ++it)
@@ -424,7 +424,7 @@ protected:
       }
       else if (!get_local_map().is_marked(it, tested))
       {
-        Dart_handle dh=it, dh_only_edge=nullptr;
+        Dart_descriptor dh=it, dh_only_edge=nullptr;
         bool degree_one=true;
         do // Here we do not use is_degree_one_face method because we want to
         {  // mark tested all darts of the face in the same loop.
@@ -453,16 +453,16 @@ protected:
     // Remove the degree-1 faces
     while (!degree_one_faces.empty())
     {
-      Dart_handle dh_face=degree_one_faces.front();
+      Dart_descriptor dh_face=degree_one_faces.front();
       degree_one_faces.pop();
       if (!get_local_map().is_marked(dh_face, edge_deleted))
       { get_local_map().template mark_cell<1>(dh_face, edge_deleted); }
       if (!get_local_map().is_marked(dh_face, face_deleted))
       { get_local_map().template mark_cell<2>(dh_face, face_deleted); }
-      Dart_handle dh_adj_face=get_local_map().opposite2(dh_face);
+      Dart_descriptor dh_adj_face=get_local_map().opposite2(dh_face);
       if (!get_local_map().is_marked(dh_adj_face, face_deleted))
       {
-        Dart_handle dh_only_edge=nullptr;
+        Dart_descriptor dh_only_edge=nullptr;
         if (is_degree_one_face(dh_adj_face, dh_only_edge, edge_deleted))
         {
           degree_one_faces.push(dh_only_edge);
@@ -488,7 +488,7 @@ protected:
     get_local_map().free_mark(face_deleted);
   }
 
-  Dart_handle nonhole_dart_of_same_edge(Dart_handle dh)
+  Dart_descriptor nonhole_dart_of_same_edge(Dart_descriptor dh)
   {
     CGAL_assertion(dh!=nullptr);
     if (get_local_map().is_marked(dh, m_is_perforated))
@@ -497,7 +497,7 @@ protected:
     return dh;
   }
 
-  Dart_handle nonhole_dart_of_same_edge(Dart_handle dh, bool& flip)
+  Dart_descriptor nonhole_dart_of_same_edge(Dart_descriptor dh, bool& flip)
   {
     CGAL_assertion(dh!=nullptr);
     if (get_local_map().is_marked(dh, m_is_perforated))
@@ -509,10 +509,10 @@ protected:
     return dh;
   }
 
-  void add_to_cycle(Dart_handle dh, Path& cycle, bool flip)
+  void add_to_cycle(Dart_descriptor dh, Path& cycle, bool flip)
   {
     dh=nonhole_dart_of_same_edge(dh, flip);
-    Original_dart_const_handle
+    Original_dart_const_descriptor
         dh_original=Get_original_dart<Self, Copy>::run(this, dh);
     if (cycle.can_be_pushed(dh_original, flip))
     { cycle.push_back(dh_original, flip, false); }
@@ -524,7 +524,7 @@ protected:
   }
 
   template <class WeightFunctor>
-  bool compute_cycle(Dart_handle root, Path& cycle,
+  bool compute_cycle(Dart_descriptor root, Path& cycle,
                      typename WeightFunctor::Weight_t* length,
                      const typename WeightFunctor::Weight_t* max_length,
                      const WeightFunctor& wf)
@@ -538,11 +538,11 @@ protected:
 
     bool first_check=true;
     typename WeightFunctor::Weight_t min_distance=0;
-    Dart_handle min_noncon_edge;
+    Dart_descriptor min_noncon_edge;
     int min_a=-1, min_b=-1;
     for (auto dh : m_noncon_edges)
     {
-      Dart_handle a=dh, b=get_local_map().next(dh);
+      Dart_descriptor a=dh, b=get_local_map().next(dh);
       int index_a=vertex_info(a), index_b=vertex_info(b);
       typename WeightFunctor::Weight_t sum_distance=
         distance_from_root[index_a]+distance_from_root[index_b]
@@ -595,3 +595,4 @@ protected:
 } // namespace CGAL
 
 #endif
+
