@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/BGL/include/CGAL/boost/graph/IO/OFF.h $
-// $Id: OFF.h a34debc 2021-06-23T22:56:35+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/BGL/include/CGAL/boost/graph/IO/OFF.h $
+// $Id: include/CGAL/boost/graph/IO/OFF.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Andreas Fabri
@@ -20,21 +20,13 @@
 
 #include <CGAL/assertions.h>
 #include <CGAL/boost/graph/Euler_operations.h>
-#include <CGAL/boost/graph/Named_function_parameters.h>
+#include <CGAL/Named_function_parameters.h>
 #include <CGAL/boost/graph/named_params_helper.h>
 
-#include <boost/utility/enable_if.hpp>
-
 #include <fstream>
 #include <iostream>
 #include <string>
 
-#ifdef DOXYGEN_RUNNING
-#define CGAL_BGL_NP_TEMPLATE_PARAMETERS NamedParameters
-#define CGAL_BGL_NP_CLASS NamedParameters
-#define CGAL_DEPRECATED
-#endif
-
 namespace CGAL {
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -71,12 +63,12 @@ public:
 
 // Because some packages can provide overloads with the same signature to automatically initialize
 // property maps (see Surface_mesh/IO/ for example)
-template <typename Graph, typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
+template <typename Graph, typename CGAL_NP_TEMPLATE_PARAMETERS>
 bool read_OFF_BGL(std::istream& is,
                   Graph& g,
-                  const CGAL_BGL_NP_CLASS& np)
+                  const CGAL_NP_CLASS& np)
 {
-  typedef typename CGAL::GetVertexPointMap<Graph, CGAL_BGL_NP_CLASS>::type  VPM;
+  typedef typename CGAL::GetVertexPointMap<Graph, CGAL_NP_CLASS>::type  VPM;
   typedef typename boost::property_traits<VPM>::value_type                  Point;
 
   internal::OFF_builder<Graph, Point> builder(is);
@@ -157,29 +149,18 @@ bool read_OFF_BGL(std::istream& is,
   \sa Overloads of this function for specific models of the concept `FaceGraph`.
 */
 template <typename Graph,
-          typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
+          typename CGAL_NP_TEMPLATE_PARAMETERS>
 bool read_OFF(std::istream& is,
               Graph& g,
-              const CGAL_BGL_NP_CLASS& np
+              const CGAL_NP_CLASS& np = parameters::default_values()
 #ifndef DOXYGEN_RUNNING
-              , typename boost::disable_if<internal::is_Point_set_or_Range_or_Iterator<Graph> >::type* = nullptr
+              , std::enable_if_t<!internal::is_Point_set_or_Range_or_Iterator<Graph>::value>* = nullptr
 #endif
               )
 {
   return internal::read_OFF_BGL(is, g, np);
 }
 
-/// \cond SKIP_IN_MANUAL
-
-template <typename Graph>
-bool read_OFF(std::istream& is, Graph& g,
-              typename boost::disable_if<internal::is_Point_set_or_Range_or_Iterator<Graph> >::type* = nullptr)
-{
-  return read_OFF(is, g, parameters::all_default());
-}
-
-/// \endcond
-
 /*!
   \ingroup PkgBGLIoFuncsOFF
 
@@ -252,12 +233,12 @@ bool read_OFF(std::istream& is, Graph& g,
   \sa Overloads of this function for specific models of the concept `FaceGraph`.
 */
 template <typename Graph,
-          typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
+          typename CGAL_NP_TEMPLATE_PARAMETERS>
 bool read_OFF(const std::string& fname,
               Graph& g,
-              const CGAL_BGL_NP_CLASS& np
+              const CGAL_NP_CLASS& np = parameters::default_values()
 #ifndef DOXYGEN_RUNNING
-              , typename boost::disable_if<internal::is_Point_set_or_Range_or_Iterator<Graph> >::type* = nullptr
+              , std::enable_if_t<!internal::is_Point_set_or_Range_or_Iterator<Graph>::value>* = nullptr
 #endif
               )
 {
@@ -265,17 +246,6 @@ bool read_OFF(const std::string& fname,
   return read_OFF(is, g, np);
 }
 
-/// \cond SKIP_IN_MANUAL
-
-template <typename Graph>
-bool read_OFF(const std::string& fname, Graph& g,
-              typename boost::disable_if<internal::is_Point_set_or_Range_or_Iterator<Graph> >::type* = nullptr)
-{
-  return read_OFF(fname, g, parameters::all_default());
-}
-
-/// \endcond
-
 } // namespace IO
 
 #ifndef CGAL_NO_DEPRECATED_CODE
@@ -285,8 +255,8 @@ bool read_OFF(const std::string& fname, Graph& g,
 
  \deprecated This function is deprecated since \cgal 5.3, `CGAL::IO::read_OFF()` should be used instead.
 */
-template <typename Graph, typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
-CGAL_DEPRECATED bool read_off(std::istream& is, Graph& g, const CGAL_BGL_NP_CLASS& np)
+template <typename Graph, typename CGAL_NP_TEMPLATE_PARAMETERS>
+CGAL_DEPRECATED bool read_off(std::istream& is, Graph& g, const CGAL_NP_CLASS& np = parameters::default_values())
 {
   return IO::read_OFF(is, g, np);
 }
@@ -296,28 +266,15 @@ CGAL_DEPRECATED bool read_off(std::istream& is, Graph& g, const CGAL_BGL_NP_CLAS
 
 \deprecated This function is deprecated since \cgal 5.3, `CGAL::IO::read_OFF()` should be used instead.
 */
-template <typename Graph, typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
-CGAL_DEPRECATED bool read_off(const char* fname, Graph& g, const CGAL_BGL_NP_CLASS& np)
+template <typename Graph, typename CGAL_NP_TEMPLATE_PARAMETERS>
+CGAL_DEPRECATED bool read_off(const char* fname, Graph& g, const CGAL_NP_CLASS& np = parameters::default_values())
 {
  return IO::read_OFF(fname, g, np);
 }
-
-template <typename Graph>
-CGAL_DEPRECATED bool read_off(std::istream& is, Graph& g)
-{
-  return read_off(is, g, parameters::all_default());
-}
-
-template <typename Graph>
-CGAL_DEPRECATED bool read_off(const char* fname, Graph& g)
-{
- return read_off(fname, g, parameters::all_default());
-}
-
 template <typename Graph>
 CGAL_DEPRECATED bool read_off(const std::string& fname, Graph& g)
 {
- return read_off(fname.c_str(), g, parameters::all_default());
+ return read_off(fname.c_str(), g, parameters::default_values());
 }
 
 #endif // CGAL_NO_DEPRECATED_CODE
@@ -329,10 +286,10 @@ CGAL_DEPRECATED bool read_off(const std::string& fname, Graph& g)
 namespace IO {
 namespace internal {
 
-template <typename Graph, typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
+template <typename Graph, typename CGAL_NP_TEMPLATE_PARAMETERS>
 bool write_OFF_BGL(std::ostream& os,
                    const Graph& g,
-                   const CGAL_BGL_NP_CLASS& np)
+                   const CGAL_NP_CLASS& np)
 {
   internal::Generic_facegraph_printer<std::ostream, Graph, CGAL::File_writer_OFF> printer(os);
   return printer(g, np);
@@ -402,29 +359,18 @@ bool write_OFF_BGL(std::ostream& os,
   \sa Overloads of this function for specific models of the concept `FaceGraph`.
 */
 template <typename Graph,
-          typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
+          typename CGAL_NP_TEMPLATE_PARAMETERS>
 bool write_OFF(std::ostream& os,
                const Graph& g,
-               const CGAL_BGL_NP_CLASS& np
+               const CGAL_NP_CLASS& np = parameters::default_values()
 #ifndef DOXYGEN_RUNNING
-               , typename boost::disable_if<internal::is_Point_set_or_Range_or_Iterator<Graph> >::type* = nullptr
+               , std::enable_if_t<!internal::is_Point_set_or_Range_or_Iterator<Graph>::value>* = nullptr
 #endif
                )
 {
   return internal::write_OFF_BGL(os, g, np);
 }
 
-/// \cond SKIP_IN_MANUAL
-
-template <typename Graph>
-bool write_OFF(std::ostream& os, const Graph& g,
-               typename boost::disable_if<internal::is_Point_set_or_Range_or_Iterator<Graph> >::type* = nullptr)
-{
-  return write_OFF(os, g, parameters::all_default());
-}
-
-/// \endcond
-
 /*!
   \ingroup PkgBGLIoFuncsOFF
 
@@ -487,12 +433,12 @@ bool write_OFF(std::ostream& os, const Graph& g,
   \sa Overloads of this function for specific models of the concept `FaceGraph`.
 */
 template <typename Graph,
-          typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
+          typename CGAL_NP_TEMPLATE_PARAMETERS>
 bool write_OFF(const std::string& fname,
                const Graph& g,
-               const CGAL_BGL_NP_CLASS& np
+               const CGAL_NP_CLASS& np = parameters::default_values()
 #ifndef DOXYGEN_RUNNING
-               , typename boost::disable_if<internal::is_Point_set_or_Range_or_Iterator<Graph> >::type* = nullptr
+               , std::enable_if_t<!internal::is_Point_set_or_Range_or_Iterator<Graph>::value>* = nullptr
 #endif
                )
 {
@@ -506,17 +452,6 @@ bool write_OFF(const std::string& fname,
   return write_OFF(os, g, np);
 }
 
-/// \cond SKIP_IN_MANUAL
-
-template <typename Graph>
-bool write_OFF(const std::string& fname, const Graph& g,
-               typename boost::disable_if<internal::is_Point_set_or_Range_or_Iterator<Graph> >::type* = nullptr)
-{
-  return write_OFF(fname, g, parameters::all_default());
-}
-
-/// \endcond
-
 } // namespace IO
 
 #ifndef CGAL_NO_DEPRECATED_CODE
@@ -526,35 +461,26 @@ bool write_OFF(const std::string& fname, const Graph& g,
 
  \deprecated This function is deprecated since \cgal 5.3, `CGAL::IO::write_OFF()` should be used instead.
 */
-template <typename Graph, typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
-CGAL_DEPRECATED bool write_off(std::ostream& os, const Graph& g, const CGAL_BGL_NP_CLASS& np)
+template <typename Graph, typename CGAL_NP_TEMPLATE_PARAMETERS>
+CGAL_DEPRECATED bool write_off(std::ostream& os, const Graph& g, const CGAL_NP_CLASS& np = parameters::default_values())
 {
   return IO::write_OFF(os, g, np);
 }
 
-template <typename Graph>
-CGAL_DEPRECATED bool write_off(std::ostream& os, const Graph& g)
-{
-  return write_off(os, g, CGAL::parameters::all_default());
-}
 /*!
 \ingroup PkgBGLIOFctDeprecated
 
 \deprecated This function is deprecated since \cgal 5.3, `CGAL::IO::write_OFF()` should be used instead.
 */
-template <typename Graph, typename CGAL_BGL_NP_TEMPLATE_PARAMETERS>
-CGAL_DEPRECATED bool write_off(const char* fname, const Graph& g, const CGAL_BGL_NP_CLASS& np)
+template <typename Graph, typename CGAL_NP_TEMPLATE_PARAMETERS>
+CGAL_DEPRECATED bool write_off(const char* fname, const Graph& g, const CGAL_NP_CLASS& np = parameters::default_values())
 {
  return IO::write_OFF(fname, g, np);
 }
 
-template <typename Graph>
-CGAL_DEPRECATED bool write_off(const char* fname, const Graph& g)
-{
-  return write_off(fname, g, parameters::all_default());
-}
 #endif // CGAL_NO_DEPRECATED_CODE
 
 } // namespace CGAL
 
 #endif // CGAL_BGL_IO_OFF_H
+
